## 更新内容

### 新功能

- 支持 Anthropic Skills 导入和使用。参见 [Skills](https://docs.astrbot.app/use/skills.html)；
- 支持新的 Tool Schema 模式：Skill-like。通过两阶段调用来减少 Tool 过多的情况下，占用过多上下文的问题。
- 支持通过环境变量配置提供商 API Key。([#4696](https://github.com/AstrBotDevs/AstrBot/issues/4696))
- 支持插件的上传文件功能配置项类型 `file` ([#4539](https://github.com/AstrBotDevs/AstrBot/issues/4539))

### 修复

- Gemini API 部分情况下工具无限循环调用 ([#4686](https://github.com/AstrBotDevs/AstrBot/issues/4686))
- 修复 WebUI GitHub 代理选择器问题及卸载插件后出现的错误 ([#4724](https://github.com/AstrBotDevs/AstrBot/issues/4724))

### 优化

- 默认不在终端显示 WebUI API 访问日志 ([#4661](https://github.com/AstrBotDevs/AstrBot/issues/4661))
- 增加插件管理页面“更新所有插件”按钮的确认对话框，防止误点击 ([#4658](https://github.com/AstrBotDevs/AstrBot/issues/4658))
